

***************************************************************************************
***************************************************************************************
*** 																				***
***  Replication data																***
*** 																				***
***  Source: Dellmuth, Lisa M. and Stoffel, Michael F., Distributive politics and 	***
***  intergovernmental transfers: The local allocation of European Union structural ***
***	 funds, European Union Politics 13 (3)											***
*** 																				***
***************************************************************************************
***************************************************************************************



*** Summary statistics

pwcorr voteshare gdp_per_capita urbanisation unemployment geo_size, sig listwise // (table 3 online appendix) //
sum totalfunding gdp_per_capita geo_size unemployment urbanisation voteshare margin // (table 2 online appendix) //

collin voteshare gdp_per_capita urbanisation unemployment geo_size


*** Regression analysis

* Spending per capita (table 2)

// Model 1 //
tobit log_funding_cap gdp_per_capita urbanisation unemployment geo_size, ll vce(cluster landid)

// Model 2 //
tobit log_funding_cap voteshare gdp_per_capita urbanisation unemployment geo_size, ll vce(cluster landid)

// Model 3 //
tobit log_funding_cap voteshare obj1_X_voteshare gdp_per_capita urbanisation unemployment geo_size, ll vce(cluster landid)

// Model 4 //
tobit log_funding_cap margin gdp_per_capita urbanisation unemployment geo_size, ll vce(cluster landid)

// Model 5 //
tobit log_funding_cap margin obj1_X_margin gdp_per_capita urbanisation unemployment geo_size, ll vce(cluster landid)

// Model 6 //
tobit log_funding_cap voteshare unemployment, ll vce(cluster landid)



* Deviation from average funding per capita

// Model 1 //
tobit devspend gdp_per_capita urbanisation unemployment geo_size, ll vce(cluster landid)

// Model 2 //
tobit devspend voteshare gdp_per_capita urbanisation unemployment geo_size, ll vce(cluster landid)

// Model 3 //
tobit devspend voteshare obj1_X_voteshare gdp_per_capita urbanisation unemployment geo_size, ll vce(cluster landid)

// Model 4 //
tobit devspend margin gdp_per_capita urbanisation unemployment geo_size, ll vce(cluster landid)

// Model 5 //
tobit devspend margin obj1_X_margin gdp_per_capita urbanisation unemployment geo_size, ll vce(cluster landid)

// Model 6 //
tobit devspend voteshare unemployment, ll vce(cluster landid)

		
		
* Local polynomial smoothing graph (figure 1)

twoway (lpolyci totalfunding voteshare if objective1==1, bwidth(6) fcolor(gs14) lcolor(gs14) graphregion(style(none) istyle(none) margin(zero)) bgcolor(white) ) (lpoly totalfunding voteshare if objective1==1, bwidth(6) lcolor(gs6) graphregion(style(none) istyle(none) margin(zero)) bgcolor(white) ) (scatter totalfunding voteshare if totalfunding<200 & objective1==1, mcolor(gs10) msize(medsmall) graphregion(style(none) istyle(none) margin(zero)) bgcolor(white) ylabel(,nogrid) ytitle(Structural Funds in Million, margin(r=1)) xtitle(Vote Share of PM Party, margin(t=1)) legend(off) title("Objective 1", color(black) margin(b=3))), name(objective1, replace) graphregion(style(none) istyle(none) margin(zero)) bgcolor(white)
twoway (lpolyci totalfunding voteshare if objective1==0, bwidth(6) fcolor(gs14) lcolor(gs14) graphregion(style(none) istyle(none) margin(zero)) bgcolor(white) ) (lpoly totalfunding voteshare if objective1==0, bwidth(6) lcolor(gs6) graphregion(style(none) istyle(none) margin(zero)) bgcolor(white) ) (scatter totalfunding voteshare if totalfunding<40 & objective1==0, mcolor(gs10) msize(medsmall) graphregion(style(none) istyle(none) margin(zero)) bgcolor(white) ylabel(,nogrid) ytitle(Structural Funds in Million, margin(r=1)) xtitle(Vote Share of PM Party, margin(t=1)) legend(off) title("Objective 2", color(black) margin(b=3))), name(objective2, replace) graphregion(style(none) istyle(none) margin(zero)) bgcolor(white)
graph combine objective1 objective2, ysize(1) xsize(2.5) iscale(*1.7) graphregion(style(none) istyle(none) margin(zero) color(white))


* Graphic of margin and vote share (figure 2)

gen voteshare2 = voteshare^2
reg margin voteshare voteshare2
predict yhat
sort voteshare
twoway (scatter margin voteshare, mcolor(gs10) msize(medsmall) graphregion(style(none) istyle(none) margin(zero) color(white))) (line yhat voteshare, lcolor(gs6) graphregion(style(none) istyle(none) margin(zero) color(white)) lwidth(medium) ylabel(,nogrid) ytitle("Marginality of District", margin(r=1)) xtitle("Vote Share of PM Party", margin(t=1)) legend(off))

corr margin voteshare
	



*** Marginal effects plots (conditional on being uncensored) (figure 3)


*** Changes in unemployment rate

quietly: sum unemployment
scalar h_Zmin = r(min)
scalar h_Zmax = r(max)
quietly: sum voteshare
scalar h_X=    r(mean)    
quietly: sum urbanisation
scalar h_Control1= r(mean)  
quietly: sum gdp_per_capita
scalar h_Control2= r(mean)  
quietly: sum geo_size
scalar h_Control3= r(mean)
scalar h_constant=1



#delimit ;

tobit log_funding_cap voteshare unemployment urbanisation gdp_per_capita geo_size, ll vce(cluster landid);
quietly: scalar tau = e(llopt);

preserve;
drawnorm MG_b1-MG_b7, n(10000) means(e(b)) cov(e(V)) clear;

postutil clear;
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi 
            using sim , replace;
            noisily display "start";
local a=h_Zmin ;
while `a' <= h_Zmax { ;

    {;

    generate x_betahat0 = MG_b1*h_X
                            + MG_b2*(`a')
                            + MG_b3*h_Control1
                            + MG_b4*h_Control2
                            + MG_b5*h_Control3
		                    + MG_b6*h_constant;
    
    
    generate x_betahat1 = MG_b1*(h_X+1)
                            + MG_b2*`a'
                            + MG_b3*h_Control1
                            + MG_b4*h_Control2
                            + MG_b5*h_Control3
							+ MG_b6*h_constant;


	gen prob0 = x_betahat0 + MG_b7*normalden((x_betahat0-tau)/MG_b7)/normal((x_betahat0-tau)/MG_b7);
	gen prob1 = x_betahat1 + MG_b7*normalden((x_betahat1-tau)/MG_b7)/normal((x_betahat1-tau)/MG_b7);


	gen diff=prob1-prob0;
    
    egen probhat0=mean(prob0);
    egen probhat1=mean(prob1);
    egen diffhat=mean(diff);
    
    tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi ;  

    _pctile prob0, p(5,95) ;
    scalar `lo0' = r(r1);
    scalar `hi0' = r(r2);  
    
    _pctile prob1, p(5,95);
    scalar `lo1'= r(r1);
    scalar `hi1'= r(r2);  
    
    _pctile diff, p(5,95);
    scalar `diff_lo'= r(r1);
    scalar `diff_hi'= r(r2);  

   
    scalar `prob_hat0'=probhat0;
    scalar `prob_hat1'=probhat1;
    scalar `diff_hat'=diffhat;
    
    post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') 
                (`diff_hat') (`diff_lo') (`diff_hi') ;
    };      
    drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat ;
    local a=`a'+ 1 ;
    display "." _c;
    } ;

display "";

postclose mypost;

use sim, clear;

gen MV = _n+h_Zmin;
sum MV, d;



graph twoway (rarea diff_hi diff_lo MV, color(gs14) lwidth(none)) (line diff_hat MV, lcolor(gs6)), bgcolor(white) graphregion(style(none) istyle(none) margin(zero) color(white)) ylabel(, nogrid glcolor(gs15)) legend(off) xtitle("") title("(a)", color(black) margin(b=3)) ytitle(Marginal Effect of Vote Share, margin(r=1)) xtitle(Unemployment Rate, margin(t=1));
		
#delimit cr
exit



*** Changes in GPD per capita

quietly: sum gdp_per_capita
scalar h_Zmin = r(min)
scalar h_Zmax = r(max)
quietly: sum voteshare
scalar h_X=    r(mean)    
quietly: sum urbanisation
scalar h_Control1= r(mean)  
quietly: sum unemployment
scalar h_Control2= r(mean)  
quietly: sum geo_size
scalar h_Control3= r(mean)
scalar h_constant=1



#delimit ;

tobit log_funding_cap voteshare gdp_per_capita urbanisation unemployment geo_size, ll vce(cluster landid);

preserve;
drawnorm MG_b1-MG_b7, n(10000) means(e(b)) cov(e(V)) clear;

postutil clear;
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi 
            using sim.dta , replace;
            noisily display "start";
            
local a=h_Zmin ;
while `a' <= h_Zmax { ;

    {;


    generate x_betahat0 = MG_b1*h_X
                            + MG_b2*(`a')
                            + MG_b3*h_Control1
                            + MG_b4*h_Control2
                            + MG_b5*h_Control3
		                    + MG_b6*h_constant;
    
    
    generate x_betahat1 = MG_b1*(h_X+1)
                            + MG_b2*`a'
                            + MG_b3*h_Control1
                            + MG_b4*h_Control2
                            + MG_b5*h_Control3
							+ MG_b6*h_constant;

	gen prob0 = x_betahat0 + MG_b7*normalden(x_betahat0/MG_b7)/normal(x_betahat0/MG_b7);
	gen prob1 = x_betahat1 + MG_b7*normalden(x_betahat1/MG_b7)/normal(x_betahat1/MG_b7);
		  
  
	gen diff=prob1-prob0;
    
    egen probhat0=mean(prob0);
    egen probhat1=mean(prob1);
    egen diffhat=mean(diff);
    
    tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi ;  

    _pctile prob0, p(5,95) ;
    scalar `lo0' = r(r1);
    scalar `hi0' = r(r2);  
    
    _pctile prob1, p(5,95);
    scalar `lo1'= r(r1);
    scalar `hi1'= r(r2);  
    
    _pctile diff, p(5,95);
    scalar `diff_lo'= r(r1);
    scalar `diff_hi'= r(r2);  

   
    scalar `prob_hat0'=probhat0;
    scalar `prob_hat1'=probhat1;
    scalar `diff_hat'=diffhat;
    
    post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') 
                (`diff_hat') (`diff_lo') (`diff_hi') ;
    };      
    drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat ;
    local a=`a'+ 1 ;
    display "." _c;
    } ;

display "";

postclose mypost;

use sim, clear;

gen MV = _n+h_Zmin;
sum MV, d;

graph twoway (rarea diff_hi diff_lo MV, color(gs14) lwidth(none)) (line diff_hat MV, lcolor(gs6)), bgcolor(white) graphregion(style(none) istyle(none) margin(zero) color(white)) ylabel(, nogrid glcolor(gs15)) legend(off) xtitle("") title("(b)", color(black) margin(b=3)) ytitle(Marginal Effect of Vote Share, margin(r=1)) xtitle(GDP per Capita in Thousand, margin(t=1));

#delimit cr
exit
